Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(853)

Unified Diff: chrome/browser/chromeos/gdata/gdata_wapi_feed_processor.h

Issue 10873005: Rename GDataDirectoryService to DriveResourceMetadata (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/gdata/gdata_wapi_feed_processor.h
diff --git a/chrome/browser/chromeos/gdata/gdata_wapi_feed_processor.h b/chrome/browser/chromeos/gdata/gdata_wapi_feed_processor.h
index 8d24b5696b4879600e735bcaf026f7b10c2bfc01..3f9cf3412f3576be095b19e19fcdd16528c083fb 100644
--- a/chrome/browser/chromeos/gdata/gdata_wapi_feed_processor.h
+++ b/chrome/browser/chromeos/gdata/gdata_wapi_feed_processor.h
@@ -17,8 +17,8 @@
namespace gdata {
class DriveDirectory;
-class GDataDirectoryService;
class DriveEntry;
+class DriveResourceMetadata;
typedef std::map<std::string /* resource_id */, DriveEntry*>
FileResourceIdMap;
@@ -38,10 +38,10 @@ struct FeedToFileResourceMapUmaStats {
// Documents List API).
class GDataWapiFeedProcessor {
public:
- explicit GDataWapiFeedProcessor(GDataDirectoryService* directory_service);
+ explicit GDataWapiFeedProcessor(DriveResourceMetadata* resource_metadata);
~GDataWapiFeedProcessor();
// Applies the documents feeds to the file system using |directory_service_|.
//
// |start_changestamp| determines the type of feed to process. The value is
// set to zero for the root feeds, every other value is for the delta feeds.
@@ -78,12 +78,12 @@ class GDataWapiFeedProcessor {
// Helper function for adding new |file| from the feed into |directory|. It
// checks the type of file and updates |changed_dirs| if this file adding
// operation needs to raise directory notification update. If file is being
// added to |orphaned_dir_service| such notifications are not raised since
// we ignore such files and don't add them to the file system now.
static void AddEntryToDirectoryAndCollectChangedDirectories(
DriveEntry* entry,
DriveDirectory* directory,
- GDataDirectoryService* orphaned_dir_service,
+ DriveResourceMetadata* orphaned_resources,
std::set<FilePath>* changed_dirs);
// Helper function for removing |entry| from |directory|. If |entry| is a
@@ -100,9 +100,9 @@ class GDataWapiFeedProcessor {
DriveDirectory* FindDirectoryForNewEntry(
DriveEntry* new_entry,
const FileResourceIdMap& file_map,
- GDataDirectoryService* orphaned_dir_service);
+ DriveResourceMetadata* orphaned_ressources);
- GDataDirectoryService* directory_service_; // Not owned by the class.
+ DriveResourceMetadata* resource_metadata_; // Not owned.
DISALLOW_COPY_AND_ASSIGN(GDataWapiFeedProcessor);
};
« no previous file with comments | « chrome/browser/chromeos/gdata/gdata_wapi_feed_loader.cc ('k') | chrome/browser/chromeos/gdata/gdata_wapi_feed_processor.cc » ('j') | no next file with comments »
@@ -38,10 +38,10 @@ struct FeedToFileResourceMapUmaStats {
~GDataWapiFeedProcessor();
- // Applies the documents feeds to the file system using |directory_service_|.
+ // Applies the documents feeds to the file system using |resource_metadata_|.
//
// |start_changestamp| determines the type of feed to process. The value is
@@ -78,12 +78,12 @@ class GDataWapiFeedProcessor {
// checks the type of file and updates |changed_dirs| if this file adding
// operation needs to raise directory notification update. If file is being
- // added to |orphaned_dir_service| such notifications are not raised since
+ // added to |orphaned_resources| such notifications are not raised since
// we ignore such files and don't add them to the file system now.
static void AddEntryToDirectoryAndCollectChangedDirectories(

Powered by Google App Engine
This is Rietveld 408576698